@@ -443,10 +443,10 @@ pub enum ErrorKind {
         name: String,
     },
 
-    /// Thrown when serializnig a bin config to JSON fails
+    /// Thrown when serializing a bin config to JSON fails
     StringifyBinConfigError,
 
-    /// Thrown when serializnig a package config to JSON fails
+    /// Thrown when serializing a package config to JSON fails
     StringifyPackageConfigError,
 
     /// Thrown when serializing the platform to JSON fails
@@ -948,7 +948,7 @@ Use `volta pin yarn` to select a version (see `volta help pin` for more info)."
             ErrorKind::NoShellProfile { env_profile, bin_dir } => write!(
                 f,
                 "Could not locate user profile.
-Tried $PROFILE ({}), ~/.bashrc, ~/.bash_profile, ~/.zshrc, ~/.profile, and ~/.config/fish/config.fish
+Tried $PROFILE ({}), ~/.bashrc, ~/.bash_profile, ~/.zshenv ~/.zshrc, ~/.profile, and ~/.config/fish/config.fish
 
 Please create one of these and try again; or you can edit your profile manually to add '{}' to your PATH",
                 env_profile, bin_dir.display()
