@@ -1,15 +1,13 @@
-use structopt::StructOpt;
-
 use volta_core::error::{ExitCode, Fallible};
 use volta_core::session::{ActivityKind, Session};
 use volta_core::tool;
 
 use crate::command::Command;
 
-#[derive(StructOpt)]
+#[derive(clap::Args)]
 pub(crate) struct Fetch {
     /// Tools to fetch, like `node`, `yarn@latest` or `your-package@^14.4.3`.
-    #[structopt(name = "tool[@version]", required = true, min_values = 1)]
+    #[arg(value_name = "tool[@version]", required = true)]
     tools: Vec<String>,
 }
 
