@@ -10,7 +10,7 @@ fn shows_pretty_error_when_calling_shim_directly() {
     let s = sandbox().build();
 
     assert_that!(
-        s.process(&shim_exe()),
+        s.process(shim_exe()),
         execs()
             .with_status(ExitCode::ExecutionFailure as i32)
             .with_stderr_contains("[..]should not be called directly[..]")
