@@ -17,7 +17,7 @@ fn shim_skips_platform_checks_on_bypass() {
 
     #[cfg(unix)]
     assert_that!(
-        s.process(&shim_exe()),
+        s.process(shim_exe()),
         execs()
             .with_status(ExitCode::ExecutionFailure as i32)
             .with_stderr_contains("VOLTA_BYPASS is enabled[..]")
@@ -25,7 +25,7 @@ fn shim_skips_platform_checks_on_bypass() {
 
     #[cfg(windows)]
     assert_that!(
-        s.process(&shim_exe()),
+        s.process(shim_exe()),
         execs()
             .with_status(ExitCode::UnknownError as i32)
             .with_stderr_contains("[..]is not recognized as an internal or external command[..]")
